==> pulumi-azure-native-kotlin-2.30.0.0-sources.jar: com/pulumi/azurenative/costmanagement/kotlin/inputs/ReportConfigFilterArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.costmanagement.kotlin.inputs

import com.pulumi.azurenative.costmanagement.inputs.ReportConfigFilterArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.applySuspend
import kotlin.Suppress
import kotlin.Unit
import kotlin.collections.List
import kotlin.jvm.JvmName

/**
 * The filter expression to be used in the report.
 * @property and The logical "AND" expression. Must have at least 2 items.
 * @property dimensions Has comparison expression for a dimension
 * @property or The logical "OR" expression. Must have at least 2 items.
 * @property tags Has comparison expression for a tag
 */
public data class ReportConfigFilterArgs(
    public val and: Output<List<ReportConfigFilterArgs>>? = null,
    public val dimensions: Output<ReportConfigComparisonExpressionArgs>? = null,
    public val or: Output<List<ReportConfigFilterArgs>>? = null,
    public val tags: Output<ReportConfigComparisonExpressionArgs>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.costmanagement.inputs.ReportConfigFilterArgs> {
    override fun toJava(): com.pulumi.azurenative.costmanagement.inputs.ReportConfigFilterArgs =
        com.pulumi.azurenative.costmanagement.inputs.ReportConfigFilterArgs.builder()
            .and(and?.applyValue({ args0 -> args0.map({ args0 -> args0.let({ args0 -> args0.toJava() }) }) }))
            .dimensions(dimensions?.applyValue({ args0 -> args0.let({ args0 -> args0.toJava() }) }))
            .or(or?.applyValue({ args0 -> args0.map({ args0 -> args0.let({ args0 -> args0.toJava() }) }) }))
            .tags(tags?.applyValue({ args0 -> args0.let({ args0 -> args0.toJava() }) })).build()
}

/**
 * Builder for [ReportConfigFilterArgs].
 */
@PulumiTagMarker
public class ReportConfigFilterArgsBuilder internal constructor() {
    private var and: Output<List<ReportConfigFilterArgs>>? = null

    private var dimensions: Output<ReportConfigComparisonExpressionArgs>? = null

    private var or: Output<List<ReportConfigFilterArgs>>? = null

    private var tags: Output<ReportConfigComparisonExpressionArgs>? = null

    /**
     * @param value The logical "AND" expression. Must have at least 2 items.
     */
    @JvmName("anxhevsybsovmerk")
    public suspend fun and(`value`: Output<List<ReportConfigFilterArgs>>) {
        this.and = value
    }

    @JvmName("rnbnxkyegxewppwi")
    public suspend fun and(vararg values: Output<ReportConfigFilterArgs>) {
        this.and = Output.all(values.asList())
    }

    /**
     * @param values The logical "AND" expression. Must have at least 2 items.
     */
    @JvmName("odrrhmmxknjvlkvn")
    public suspend fun and(values: List<Output<ReportConfigFilterArgs>>) {
        this.and = Output.all(values)
    }

    /**
     * @param value Has comparison expression for a dimension
     */
    @JvmName("lqtvwtufnohdesdr")
    public suspend fun dimensions(`value`: Output<ReportConfigComparisonExpressionArgs>) {
        this.dimensions = value
    }

    /**
     * @param value The logical "OR" expression. Must have at least 2 items.
     */
    @JvmName("mgauvwftvaqqjdyt")
    public suspend fun or(`value`: Output<List<ReportConfigFilterArgs>>) {
        this.or = value
    }

    @JvmName("smfmjokfosjlugrg")
    public suspend fun or(vararg values: Output<ReportConfigFilterArgs>) {
        this.or = Output.all(values.asList())
    }

    /**
     * @param values The logical "OR" expression. Must have at least 2 items.
     */
    @JvmName("gfwdtggoxgbtljld")
    public suspend fun or(values: List<Output<ReportConfigFilterArgs>>) {
        this.or = Output.all(values)
    }

    /**
     * @param value Has comparison expression for a tag
     */
    @JvmName("cofnjkcxeqdyhvgi")
    public suspend fun tags(`value`: Output<ReportConfigComparisonExpressionArgs>) {
        this.tags = value
    }

    /**
     * @param value The logical "AND" expression. Must have at least 2 items.
     */
    @JvmName("midaagoulvmgbrhc")
    public suspend fun and(`value`: List<ReportConfigFilterArgs>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.and = mapped
    }

    /**
     * @param argument The logical "AND" expression. Must have at least 2 items.
     */
    @JvmName("ikhyafpfhyhkhgbi")
    public suspend fun and(argument: List<suspend ReportConfigFilterArgsBuilder.() -> Unit>) {
        val toBeMapped = argument.toList().map {
            ReportConfigFilterArgsBuilder().applySuspend {
                it()
            }.build()
        }
        val mapped = of(toBeMapped)
        this.and = mapped
    }

    /**
     * @param argument The logical "AND" expression. Must have at least 2 items.
     */
    @JvmName("vugdhcniyfldixbx")
    public suspend fun and(vararg argument: suspend ReportConfigFilterArgsBuilder.() -> Unit) {
        val toBeMapped = argument.toList().map {
            ReportConfigFilterArgsBuilder().applySuspend {
                it()
            }.build()
        }
        val mapped = of(toBeMapped)
        this.and = mapped
    }

    /**
     * @param argument The logical "AND" expression. Must have at least 2 items.
     */
    @JvmName("svfvpxwbcwbfjjsn")
    public suspend fun and(argument: suspend ReportConfigFilterArgsBuilder.() -> Unit) {
        val toBeMapped = listOf(ReportConfigFilterArgsBuilder().applySuspend { argument() }.build())
        val mapped = of(toBeMapped)
        this.and = mapped
    }

    /**
     * @param values The logical "AND" expression. Must have at least 2 items.
     */
    @JvmName("cslomvkyymaoynrd")
    public suspend fun and(vararg values: ReportConfigFilterArgs) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.and = mapped
    }

    /**
     * @param value Has comparison expression for a dimension
     */
    @JvmName("olhnducqrchilxfy")
    public suspend fun dimensions(`value`: ReportConfigComparisonExpressionArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.dimensions = mapped
    }

    /**
     * @param argument Has comparison expression for a dimension
     */
    @JvmName("fkphofplhfmylern")
    public suspend
    fun dimensions(argument: suspend ReportConfigComparisonExpressionArgsBuilder.() -> Unit) {
        val toBeMapped = ReportConfigComparisonExpressionArgsBuilder().applySuspend {
            argument()
        }.build()
        val mapped = of(toBeMapped)
        this.dimensions = mapped
    }

    /**
     * @param value The logical "OR" expression. Must have at least 2 items.
     */
    @JvmName("mxaqunvnphwionkx")
    public suspend fun or(`value`: List<ReportConfigFilterArgs>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.or = mapped
    }

    /**
     * @param argument The logical "OR" expression. Must have at least 2 items.
     */
    @JvmName("hshakhatuuiewhwe")
    public suspend fun or(argument: List<suspend ReportConfigFilterArgsBuilder.() -> Unit>) {
        val toBeMapped = argument.toList().map {
            ReportConfigFilterArgsBuilder().applySuspend {
                it()
            }.build()
        }
        val mapped = of(toBeMapped)
        this.or = mapped
    }

    /**
     * @param argument The logical "OR" expression. Must have at least 2 items.
     */
    @JvmName("qgcrlsxdagepldfu")
    public suspend fun or(vararg argument: suspend ReportConfigFilterArgsBuilder.() -> Unit) {
        val toBeMapped = argument.toList().map {
            ReportConfigFilterArgsBuilder().applySuspend {
                it()
            }.build()
        }
        val mapped = of(toBeMapped)
        this.or = mapped
    }

    /**
     * @param argument The logical "OR" expression. Must have at least 2 items.
     */
    @JvmName("oesqcfnmfpymmgca")
    public suspend fun or(argument: suspend ReportConfigFilterArgsBuilder.() -> Unit) {
        val toBeMapped = listOf(ReportConfigFilterArgsBuilder().applySuspend { argument() }.build())
        val mapped = of(toBeMapped)
        this.or = mapped
    }

    /**
     * @param values The logical "OR" expression. Must have at least 2 items.
     */
    @JvmName("fwnhyawycjjxjvhw")
    public suspend fun or(vararg values: ReportConfigFilterArgs) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.or = mapped
    }

    /**
     * @param value Has comparison expression for a tag
     */
    @JvmName("wjppdkluwowacctj")
    public suspend fun tags(`value`: ReportConfigComparisonExpressionArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.tags = mapped
    }

    /**
     * @param argument Has comparison expression for a tag
     */
    @JvmName("wafsvxqjumxhwgbb")
    public suspend
    fun tags(argument: suspend ReportConfigComparisonExpressionArgsBuilder.() -> Unit) {
        val toBeMapped = ReportConfigComparisonExpressionArgsBuilder().applySuspend {
            argument()
        }.build()
        val mapped = of(toBeMapped)
        this.tags = mapped
    }

    internal fun build(): ReportConfigFilterArgs = ReportConfigFilterArgs(
        and = and,
        dimensions = dimensions,
        or = or,
        tags = tags,
    )
}

==> pulumi-azure-native-kotlin-2.37.0.0-sources.jar: com/pulumi/azurenative/costmanagement/kotlin/inputs/ReportConfigFilterArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.costmanagement.kotlin.inputs

import com.pulumi.azurenative.costmanagement.inputs.ReportConfigFilterArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.applySuspend
import kotlin.Suppress
import kotlin.Unit
import kotlin.collections.List
import kotlin.jvm.JvmName

/**
 * The filter expression to be used in the report.
 * @property and The logical "AND" expression. Must have at least 2 items.
 * @property dimensions Has comparison expression for a dimension
 * @property or The logical "OR" expression. Must have at least 2 items.
 * @property tags Has comparison expression for a tag
 */
public data class ReportConfigFilterArgs(
    public val and: Output<List<ReportConfigFilterArgs>>? = null,
    public val dimensions: Output<ReportConfigComparisonExpressionArgs>? = null,
    public val or: Output<List<ReportConfigFilterArgs>>? = null,
    public val tags: Output<ReportConfigComparisonExpressionArgs>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.costmanagement.inputs.ReportConfigFilterArgs> {
    override fun toJava(): com.pulumi.azurenative.costmanagement.inputs.ReportConfigFilterArgs =
        com.pulumi.azurenative.costmanagement.inputs.ReportConfigFilterArgs.builder()
            .and(and?.applyValue({ args0 -> args0.map({ args0 -> args0.let({ args0 -> args0.toJava() }) }) }))
            .dimensions(dimensions?.applyValue({ args0 -> args0.let({ args0 -> args0.toJava() }) }))
            .or(or?.applyValue({ args0 -> args0.map({ args0 -> args0.let({ args0 -> args0.toJava() }) }) }))
            .tags(tags?.applyValue({ args0 -> args0.let({ args0 -> args0.toJava() }) })).build()
}

/**
 * Builder for [ReportConfigFilterArgs].
 */
@PulumiTagMarker
public class ReportConfigFilterArgsBuilder internal constructor() {
    private var and: Output<List<ReportConfigFilterArgs>>? = null

    private var dimensions: Output<ReportConfigComparisonExpressionArgs>? = null

    private var or: Output<List<ReportConfigFilterArgs>>? = null

    private var tags: Output<ReportConfigComparisonExpressionArgs>? = null

    /**
     * @param value The logical "AND" expression. Must have at least 2 items.
     */
    @JvmName("cjtecqiapumxftlu")
    public suspend fun and(`value`: Output<List<ReportConfigFilterArgs>>) {
        this.and = value
    }

    @JvmName("xcshuamatfundlcw")
    public suspend fun and(vararg values: Output<ReportConfigFilterArgs>) {
        this.and = Output.all(values.asList())
    }

    /**
     * @param values The logical "AND" expression. Must have at least 2 items.
     */
    @JvmName("jbtxeoebimrubpvv")
    public suspend fun and(values: List<Output<ReportConfigFilterArgs>>) {
        this.and = Output.all(values)
    }

    /**
     * @param value Has comparison expression for a dimension
     */
    @JvmName("sfwdgeatnvoswrym")
    public suspend fun dimensions(`value`: Output<ReportConfigComparisonExpressionArgs>) {
        this.dimensions = value
    }

    /**
     * @param value The logical "OR" expression. Must have at least 2 items.
     */
    @JvmName("adeauatkibsebadf")
    public suspend fun or(`value`: Output<List<ReportConfigFilterArgs>>) {
        this.or = value
    }

    @JvmName("tkgwvxtfmhiyfbhe")
    public suspend fun or(vararg values: Output<ReportConfigFilterArgs>) {
        this.or = Output.all(values.asList())
    }

    /**
     * @param values The logical "OR" expression. Must have at least 2 items.
     */
    @JvmName("esvptaeprpgvvmse")
    public suspend fun or(values: List<Output<ReportConfigFilterArgs>>) {
        this.or = Output.all(values)
    }

    /**
     * @param value Has comparison expression for a tag
     */
    @JvmName("trorgetkvsdgmash")
    public suspend fun tags(`value`: Output<ReportConfigComparisonExpressionArgs>) {
        this.tags = value
    }

    /**
     * @param value The logical "AND" expression. Must have at least 2 items.
     */
    @JvmName("fjekorovvkokpwsk")
    public suspend fun and(`value`: List<ReportConfigFilterArgs>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.and = mapped
    }

    /**
     * @param argument The logical "AND" expression. Must have at least 2 items.
     */
    @JvmName("rwbxcdiahlqxvsfq")
    public suspend fun and(argument: List<suspend ReportConfigFilterArgsBuilder.() -> Unit>) {
        val toBeMapped = argument.toList().map {
            ReportConfigFilterArgsBuilder().applySuspend {
                it()
            }.build()
        }
        val mapped = of(toBeMapped)
        this.and = mapped
    }

    /**
     * @param argument The logical "AND" expression. Must have at least 2 items.
     */
    @JvmName("hbatjthvoohenkuk")
    public suspend fun and(vararg argument: suspend ReportConfigFilterArgsBuilder.() -> Unit) {
        val toBeMapped = argument.toList().map {
            ReportConfigFilterArgsBuilder().applySuspend {
                it()
            }.build()
        }
        val mapped = of(toBeMapped)
        this.and = mapped
    }

    /**
     * @param argument The logical "AND" expression. Must have at least 2 items.
     */
    @JvmName("fdsdyrhcfylxcfdk")
    public suspend fun and(argument: suspend ReportConfigFilterArgsBuilder.() -> Unit) {
        val toBeMapped = listOf(ReportConfigFilterArgsBuilder().applySuspend { argument() }.build())
        val mapped = of(toBeMapped)
        this.and = mapped
    }

    /**
     * @param values The logical "AND" expression. Must have at least 2 items.
     */
    @JvmName("xthniypawetqmlcs")
    public suspend fun and(vararg values: ReportConfigFilterArgs) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.and = mapped
    }

    /**
     * @param value Has comparison expression for a dimension
     */
    @JvmName("wdiacxkicxhhnmmy")
    public suspend fun dimensions(`value`: ReportConfigComparisonExpressionArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.dimensions = mapped
    }

    /**
     * @param argument Has comparison expression for a dimension
     */
    @JvmName("acnxuqamuhfvnfxe")
    public suspend
    fun dimensions(argument: suspend ReportConfigComparisonExpressionArgsBuilder.() -> Unit) {
        val toBeMapped = ReportConfigComparisonExpressionArgsBuilder().applySuspend {
            argument()
        }.build()
        val mapped = of(toBeMapped)
        this.dimensions = mapped
    }

    /**
     * @param value The logical "OR" expression. Must have at least 2 items.
     */
    @JvmName("rjhqfmycwythfrms")
    public suspend fun or(`value`: List<ReportConfigFilterArgs>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.or = mapped
    }

    /**
     * @param argument The logical "OR" expression. Must have at least 2 items.
     */
    @JvmName("ernljcqcgelwkwkg")
    public suspend fun or(argument: List<suspend ReportConfigFilterArgsBuilder.() -> Unit>) {
        val toBeMapped = argument.toList().map {
            ReportConfigFilterArgsBuilder().applySuspend {
                it()
            }.build()
        }
        val mapped = of(toBeMapped)
        this.or = mapped
    }

    /**
     * @param argument The logical "OR" expression. Must have at least 2 items.
     */
    @JvmName("yiafkdapyfiltdel")
    public suspend fun or(vararg argument: suspend ReportConfigFilterArgsBuilder.() -> Unit) {
        val toBeMapped = argument.toList().map {
            ReportConfigFilterArgsBuilder().applySuspend {
                it()
            }.build()
        }
        val mapped = of(toBeMapped)
        this.or = mapped
    }

    /**
     * @param argument The logical "OR" expression. Must have at least 2 items.
     */
    @JvmName("msgmmxkpihhopehu")
    public suspend fun or(argument: suspend ReportConfigFilterArgsBuilder.() -> Unit) {
        val toBeMapped = listOf(ReportConfigFilterArgsBuilder().applySuspend { argument() }.build())
        val mapped = of(toBeMapped)
        this.or = mapped
    }

    /**
     * @param values The logical "OR" expression. Must have at least 2 items.
     */
    @JvmName("dipjnphdqnigjdbc")
    public suspend fun or(vararg values: ReportConfigFilterArgs) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.or = mapped
    }

    /**
     * @param value Has comparison expression for a tag
     */
    @JvmName("abltwnhntbgcmvqs")
    public suspend fun tags(`value`: ReportConfigComparisonExpressionArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.tags = mapped
    }

    /**
     * @param argument Has comparison expression for a tag
     */
    @JvmName("gamrfxmrrctfdnen")
    public suspend
    fun tags(argument: suspend ReportConfigComparisonExpressionArgsBuilder.() -> Unit) {
        val toBeMapped = ReportConfigComparisonExpressionArgsBuilder().applySuspend {
            argument()
        }.build()
        val mapped = of(toBeMapped)
        this.tags = mapped
    }

    internal fun build(): ReportConfigFilterArgs = ReportConfigFilterArgs(
        and = and,
        dimensions = dimensions,
        or = or,
        tags = tags,
    )
}
